@@ -10,8 +10,9 @@ package org.freedesktop.cairo;
 
 public class RadialGradient extends Gradient {
 
-    public RadialGradient(double x1, double y1, double radius1, double x2, double y2, double radius2) {
+    public RadialGradient(double x1, double y1, double radius1, double x2,
+            double y2, double radius2) {
         super(cairo_pattern_create_radial(x1, y1, radius1, x1, y2, radius2));
     }
-    
+
 }
